@@ -13,6 +13,7 @@ from . import run_auto_relativeParagraph as rarp
 from . import run_auto_contentImgs as raci
 from . import run_auto_thumbnailImgs as rati
 from . import run_auto_comment as rac
+from . import run_auto_selenium as ras
 from .articlesRef.DatabaserOperator import databaseOperator as dbOp
 from . import run_auto_video as rav
 
@@ -89,6 +90,16 @@ class TimedTaskBasic():
         self.thread = threading.Timer(wait_time,self.func1)    # 当前线程
         self.thread.start()
 
+# 永久执行任务
+class PermanentTask(TimedTaskBasic):
+    # 任务描述：永久任务 隔3600秒执行一次task任务
+    def func1(self):
+        # 该任务设置的
+        #   beginTime="00:01:00"
+        #   endTime="23:59:00"
+        self.func2()
+
+
 # 2. 定时任务 ———— 爬取数据的的类
 class TimedTask4Spider(TimedTaskBasic):
     def task(self):
@@ -145,14 +156,15 @@ class TimedTask4AutoDealwithPost(TimedTaskBasic):
         elif(self.setting["whichKind"] == 'relativeParagraph'):
             rarp.run(setting=self.setting)
         elif(self.setting["whichKind"] == 'contentImgs'):
-            raci.run(proj_absPath=self.setting["proj_absPath"], oriDomain=self.setting["oriDomain"], database=self.setting['databaseName'], tableNameList=self.setting['tableName'])
+            raci.run(proj_absPath=self.setting["proj_absPath"], oriDomain=self.setting["oriDomain"], database=self.setting['databaseName'], tableNameList=self.setting['tableName'], maskFilt=self.setting['maskFilt'])
         elif(self.setting["whichKind"] == 'thumbnailImgs'):
             rati.run(proj_absPath=self.setting["proj_absPath"], oriDomain=self.setting["oriDomain"], database=self.setting['databaseName'], tableNameList=self.setting['tableName'])
-        elif(self.setting["whichKind"]=='video'):
+        elif (self.setting['whichKind'] == 'video' and self.setting['crawlMethod'] == 'Selenium'):
+            ras.run_douyin(proj_absPath=self.setting["proj_absPath"], crawlUrl_list=self.setting['crawlUrl_list'],oriDomain=self.setting["oriDomain"])
+        elif(self.setting["whichKind"]=='video' and self.setting['crawlMethod'] == 'Scrapy'):
             rav.run_bilibili(setting=self.setting)
         elif(self.setting["whichKind"]=='articleComment'):
             rac.run(setting=self.setting)
-            print("articleComment")
         print("上传数据完成，接下来清空数据库")
         # 上传完直接清空数据库，不用再用定时器
         clearDB = TimedTask4AutoClearDB(setting=self.setting)
@@ -279,48 +291,3 @@ class TimedTask4AutoClearDB(TimedTaskBasic):
                     dbOperator.cursor.execute(sql4truncate)
                 dbOperator.closeDb()
 
-if(__name__ == '__main__'):
-    '''
-        下面是对股票代码数据的爬取流程自动化操作 测试
-    '''
-    setting4Spider = {
-        "spiderPath": "E:\\Projects\\Crawl_Dealwith_Post_Auto\\stocksNameCode_Crawl_Auto\\stocksNameCode_Crawl_Auto",
-        "spiderName": "StcockNameCodeSpider",
-        "command": "Scrapy crawl StcockNameCodeSpider",
-        "beginTime" : '08:00:00', # 注意表示 一位数字的要0开头
-        "endTime" : '09:00:00',
-        "excuteDelta" : 3600  # 间隔1h 也就是说一天执行一次
-    }
-    # setting4AutoDP = {
-    #     "beginTime": '08:00:00',  # 注意表示 一位数字的要0开头
-    #     "endTime": '09:00:00',
-    #     "excuteDelta": 3600,  # 间隔1h 也就是说一天执行一次
-    #     "whichKind": 'keyParagraph'
-    # }
-    setting4AutoCDB = {
-        "beginTime": '08:00:00',  # 注意表示 一位数字的要0开头
-        "endTime": '09:00:00',
-        "excuteDelta": 3600,  # 间隔1h 也就是说一天执行一次
-        "whichKind": 'keyParagraph',
-        "databaseName" : 'stocksnamecode',   # 对应的数据库名
-        "tableName" : 'tb_namecode'    # 待清空的表名
-    }
-
-    # # 创建定时任务器 -- Spider任务
-    # timedTask1_Spider = TimedTask4Spider(setting=setting4Spider, beginTime=setting4Spider["beginTime"], endTime=setting4Spider["endTime"], excuteDelta=setting4Spider["excuteDelta"])
-    # timedTask1_Spider.task(setting=setting4Spider)
-    # timedTask1_Spider.timedTaskRun()
-    #
-    # # 2 定时器 ———— 处理和上传数据
-    # timedTask1_autoDP = TimedTask4AutoDealwithPost()
-    # # timedTask1_autoDP.task(setting=setting4AutoDP)
-    # timedTask1_autoDP.timedTaskRun()
-
-    # # 3 定时器 ———— 删除数据库对应上传完成的数据
-    # timedTask1_autoCDB = TimedTask4AutoClearDB()
-    # timedTask1_autoCDB.task(setting=setting4AutoCDB)
-
-    # 创建定时任务器 -- Spider任务
-    timedTask1_Spider = TimedTaskBasic()
-    # timedTask1_Spider.task(setting=setting4Spider)
-    timedTask1_Spider.timedTaskRun()
\ No newline at end of file
